@@ -1,5 +1,7 @@
 #!/usr/bin/env python3
 
+from typing import Union
+
 import aiohttp
 
 from gv_utils import parser
@@ -42,6 +44,9 @@ class Requests:
         return await self._get(SEPARATOR.join((RequestPath.road, RequestPath.roadcenter, RequestPath.turnratio)),
                                params)
 
+    async def get_prediction_point(self) -> list:
+        return await self._get(RequestPath.predictionpoint)
+
     async def get_zone_point(self, zoneeids: list = None, area: BaseGeometry = None) -> list:
         return await self._get_location(zoneeids, area, RequestPath.zonepoint)
 
@@ -65,7 +70,7 @@ class Requests:
 
     async def get_data_point_data_quality(self, fromdatetime: datetime, todatetime: datetime = None,
                                           datapointeids: list = None, datatypeeids: list = None, period: str = None,
-                                          sampling: str = None, window: str = None) -> list:
+                                          sampling: str = None, window: str = None) -> dict:
         params = {}
         if datatypeeids is not None:
             params[RequestParam.datatype] = self.__encode_list_params(datatypeeids)
@@ -74,58 +79,39 @@ class Requests:
 
     async def get_data_type_data_quality(self, fromdatetime: datetime, todatetime: datetime = None,
                                          datatypeeids: list = None, period: str = None, sampling: str = None,
-                                         window: str = None) -> list:
+                                         window: str = None) -> dict:
         return await self._get_data_quality(fromdatetime, todatetime, datatypeeids, period, sampling, window,
                                             RequestPath.datatype)
 
     async def get_road_data_quality(self, fromdatetime: datetime, todatetime: datetime = None, roadeids: list = None,
-                                    period: str = None, sampling: str = None, window: str = None) -> list:
+                                    period: str = None, sampling: str = None, window: str = None) -> dict:
         return await self._get_data_quality(fromdatetime, todatetime, roadeids, period, sampling, window,
                                             RequestPath.road)
 
     async def _get_data_quality(self, fromdatetime: datetime, todatetime: datetime, locationeids: list,
-                                period: str, sampling: str, window: str, applyto: str, params: dict = None) -> list:
+                                period: str, sampling: str, window: str, applyto: str, params: dict = None) -> dict:
         return await self.__get_data(fromdatetime, todatetime, locationeids, period, sampling, window,
                                      SEPARATOR.join((applyto, RequestPath.dataquality)), params)
 
     async def get_data_point_indicator(self, indicator: str, fromdatetime: datetime,
                                        todatetime: datetime = None, datapointeids: list = None,
                                        datatypeeids: list = None, period: str = None, sampling: str = None,
-                                       window: str = None) -> list:
-        params = {}
+                                       window: str = None) -> dict:
+        params = {RequestParam.indicator: indicator}
         if datatypeeids is not None:
             params[RequestParam.datatype] = self.__encode_list_params(datatypeeids)
-        return await self._get_data_point_indicator(indicator, fromdatetime, todatetime, datapointeids, period,
-                                                    sampling, window, RequestPath.datapoint, params)
-
-    async def get_data_point_imputed_indicator(self, indicator: str, fromdatetime: datetime,
-                                               todatetime: datetime = None, datapointeids: list = None,
-                                               datatypeeids: list = None, period: str = None, sampling: str = None,
-                                               window: str = None) -> list:
-        params = {}
-        if datatypeeids is not None:
-            params[RequestParam.datatype] = self.__encode_list_params(datatypeeids)
-        return await self._get_data_point_indicator(indicator, fromdatetime, todatetime, datapointeids, period,
-                                                    sampling, window, SEPARATOR.join((RequestPath.datapoint,
-                                                                                      RequestPath.imputed)), params)
-
-    async def _get_data_point_indicator(self, indicator: str, fromdatetime: datetime, todatetime: datetime,
-                                        locationeids: list, period: str, sampling: str, window: str, applyto: str,
-                                        params: dict = None) -> list:
-        if params is None:
-            params = {}
-        params[RequestParam.indicator] = indicator
-        return await self.__get_data(fromdatetime, todatetime, locationeids, period, sampling, window,
-                                     SEPARATOR.join((applyto, RequestPath.indicator)), params)
+        return await self.__get_data(fromdatetime, todatetime, datapointeids, period, sampling, window,
+                                     SEPARATOR.join((RequestPath.datapoint, RequestPath.indicator)), params)
 
     async def get_road_indicator(self, indicator: str, fromdatetime: datetime, todatetime: datetime,
                                  roadeids: list = None, period: str = None, sampling: str = None,
-                                 window: str = None) -> list:
+                                 window: str = None) -> dict:
+        params = {RequestParam.indicator: indicator}
         return await self.__get_data(fromdatetime, todatetime, roadeids, period, sampling, window,
-                                     SEPARATOR.join((RequestPath.road, RequestPath.indicator, indicator)), {})
+                                     SEPARATOR.join((RequestPath.road, RequestPath.indicator, indicator)), params)
 
     async def __get_data(self, fromdatetime: datetime, todatetime: datetime, locationeids: list, period: str,
-                         sampling: str, window: str, applyto: str, params) -> list:
+                         sampling: str, window: str, applyto: str, params: dict) -> dict:
         if params is None:
             params = {}
 
@@ -142,11 +128,9 @@ class Requests:
             params[RequestParam.window] = window
         return await self._get(applyto, params)
 
-    async def get_zone_travel_time(self, frompointeid: str, topointeid: str, fromdatetime: datetime,
-                                   todatetime: datetime, period: str, sampling: str) -> list:
+    async def get_zone_travel_time(self, fromdatetime: datetime, todatetime: datetime, period: str, sampling: str,
+                                   frompointeid: str = None, topointeid: str = None) -> dict:
         params = {
-            RequestParam.frompoint: frompointeid,
-            RequestParam.topoint: topointeid,
             RequestParam.fromdatetime: to_str(fromdatetime)
         }
         if todatetime is not None:
@@ -155,9 +139,13 @@ class Requests:
             params[RequestParam.period] = period
         if sampling is not None:
             params[RequestParam.sampling] = sampling
+        if frompointeid is not None:
+            params[RequestParam.frompoint] = frompointeid
+        if topointeid is not None:
+            params[RequestParam.topoint] = topointeid
         return await self._get(SEPARATOR.join((RequestPath.zonepoint, RequestPath.traveltime)), params)
 
-    async def _get(self, suffix: str, params: dict = None) -> list:
+    async def _get(self, suffix: str, params: dict = None) -> Union[list, dict]:
         if params is None:
             params = {}
         params[RequestParam.internalflag] = ''
