@@ -10,10 +10,10 @@ def load_env_var(filepath: str) -> (str, str):
 
     envloaded = os.environ.get('ENV_LOADED', False)
     if envloaded:
-        dotenv_path = os.path.join(PROJECT_ROOT, '.env')
+        dotenv_path = os.path.join(projectroot, '.env')
         load_dotenv(dotenv_path)
         envtype = os.environ.get('ENV_TYPE', default='local')
-        load_dotenv(dotenv_path + '.' + ENV_TYPE)
+        load_dotenv(dotenv_path + '.' + envtype)
     else:
         envtype = os.environ.get('ENV_TYPE', default='local')
 
